@@ -10,7 +10,7 @@ import logging
 from time import sleep
 import requests
 
-from flask import Flask, request
+from flask import Flask, request, render_template
 from werkzeug.serving import make_server
 from suite_py.lib.handler.qainit_handler import QainitHandler as qainit
 
@@ -23,7 +23,7 @@ error_message = None
 received_state = None
 
 ## Global Flask App
-app = Flask(__name__)
+app = Flask(__name__, template_folder="templates")
 log = logging.getLogger("werkzeug")
 log.disabled = True
 
@@ -45,7 +45,7 @@ def callback():
         code = request.args["code"]
     received_state = request.args["state"]
     received_callback = True
-    return "Please return to your application now."
+    return render_template("login.html")
 
 
 class ServerThread(threading.Thread):
@@ -140,7 +140,7 @@ class Login:
         # Start the server
         # Poll til the callback has been invoked
         received_callback = False
-        webbrowser.open_new(url)
+        webbrowser.open(url)
         server = ServerThread(app)
         server.start()
         while not received_callback:
